======
Binary
======

The following methods are available under the `expr.bin` attribute.

.. currentmodule:: polars
.. autosummary::
   :toctree: api/
   :template: autosummary/accessor_method.rst

    Expr.bin.contains
    Expr.bin.decode
    Expr.bin.encode
    Expr.bin.ends_with
    Expr.bin.starts_with
